/**<pre>
 * Title: iSIM
 * Copyright: Copyright (c) 2002
 * Company:   University of Oregon Computer Science Dept.
 *
 * @author Jason Prideaux
 * @version 1.0
 * </pre>
 */

package agent;

import util.*;
import java.awt.*;


/* ====================================================================== */
/** This class represents an agent on the map.  An agent may be a User
 *  representing an emulated ipaq user, or it may be a wireless access point
 *  whose sole purpose is to help connect users.
 *  This class cannot be initiated it only defines methods and variables that
 *  will be used by specific types of Agents.
 *
 */
public abstract class Agent{

	/** The current pixel location of this user. */
  	private Point location;

	/** The current gps Position of the agent. */
  	private Position position;

	/** The wireless networking range of this agent. */
  	private int range;

	/** The name of this agent. */
  	private String name;

  	/** The health of this agent. */
  	private int health;

  	/** The oxygen of this agent. */
  	private int oxygen;

	/** The oxygen of this agent. */
  	private int weight;

  	private int floor;

  	private boolean dead;

  	private Agent carrying;


	private boolean bioSensor = true;
	private boolean locationSensor = true;
	private boolean roomSensor = true;
	private boolean wirelessSensor = true;

	private boolean bioSensor2 = true;
	private boolean locationSensor2 = true;
	private boolean roomSensor2 = true;
	private boolean wirelessSensor2 = true;


    /* ===================================================================== */
    /** This constructor initializes the agent with universal information
     *
     *  @param  n   The name of the agent.
     *  @param  l   The starting pixel location of this agent on the map.
     *  @param  p   The starting gps position of this agent on the map.
     *  @param  r   The wireless network range of the agent.
     *
     */
  	public Agent(String n, Point l, Position p, int r){

		name = n;
		position = p;
		location = l;
		range = r;

		floor = 1;
		health = 100;
		oxygen = 100;
		weight = 50;
		dead = false;

	} //Constructor



    /* ===================================================================== */
    /** This constructor initializes the agent with universal information
     *
     *  @param  l   The starting pixel location of this agent on the map.
     *  @param  p   The starting gps position of this agent on the map.
     *  @param  r   The wireless network range of the agent.
     *
     */
  	public Agent(Point l, Position p, int r){

		position = p;
		location = l;
		range = r;
		name = "";

		floor = 1;
		health = 100;
		oxygen = 100;
		weight = 50;
		dead = false;

	} //Constructor


    /* ===================================================================== */
    /** This method returns the name of this agent.
     *
     *  @return  String  The name of this agent.
     *
     */
	public String getName(){

		return name;

	} //method: getName


    /* ===================================================================== */
    /** This method sets the name of the agent.
     *
     *  @param  n   The name of this agent.
     *
     */
	public void setName(String n){

		name = n;

	} //method: setName


    /* ===================================================================== */
    /** This method returns the name of this agent.
     *
     *  @return  String  The name of this agent.
     *
     */
	public int getFloor(){

		return floor;

	} //method: getName


    /* ===================================================================== */
    /** This method sets the name of the agent.
     *
     *  @param  n   The name of this agent.
     *
     */
	public void setFloor(int n){

		floor = n;

	} //method: setName



    /* ===================================================================== */
    /** This method returns the name of this agent.
     *
     *  @return  String  The name of this agent.
     *
     */
	public int getHealth(){

		return health;

	} //method: getName


    /* ===================================================================== */
    /** This method sets the name of the agent.
     *
     *  @param  n   The name of this agent.
     *
     */
	public void setHealth(int n){

		health = n;

	} //method: setName


    /* ===================================================================== */
    /** This method returns the name of this agent.
     *
     *  @return  String  The name of this agent.
     *
     */
	public int getOxygen(){

		return oxygen;

	} //method: getName


    /* ===================================================================== */
    /** This method sets the name of the agent.
     *
     *  @param  n   The name of this agent.
     *
     */
	public void setOxygen(int n){

		oxygen = n;

	} //method: setName



    /* ===================================================================== */
    /** This method returns the name of this agent.
     *
     *  @return  String  The name of this agent.
     *
     */
	public boolean isDead(){

		return dead;

	} //method: getName


    /* ===================================================================== */
    /** This method sets the name of the agent.
     *
     *  @param  n   The name of this agent.
     *
     */
	public void setDead(boolean n){

		dead = n;

	} //method: setName


    /* ===================================================================== */
    /** This method returns the name of this agent.
     *
     *  @return  String  The name of this agent.
     *
     */
	public Agent getCarrying(){

		return carrying;

	} //method: getName


    /* ===================================================================== */
    /** This method sets the name of the agent.
     *
     *  @param  n   The name of this agent.
     *
     */
	public void setCarrying(Agent n){

		if( n == null ){
			weight -= 200;
		}else{
			weight += 200;
		}
		carrying = n;

	} //method: setName


    /* ===================================================================== */
    /** This method returns the name of this agent.
     *
     *  @return  String  The name of this agent.
     *
     */
	public int getWeight(){

		return weight;

	} //method: getName


    /* ===================================================================== */
    /** This method sets the name of the agent.
     *
     *  @param  n   The name of this agent.
     *
     */
	public void setWeight(int n){

		weight = n;

	} //method: setName


    /* ===================================================================== */
    /** This method returns the current pixel location of the agent.
     *
     *  @return  Point  The current location.
     *
     */
	public Point getLocation(){

		return location;

	} //method: getLocation



    /* ===================================================================== */
    /** This method return the current gps position of the agent.
     *
     *  @return  Position  The current position.
     *
     */
	public Position getPosition(){

		return position;

	} //method: getPosition



    /* ===================================================================== */
    /** This method returns the range of the agent.
     *
     *  @return  int  The range in pixels.
     *
     */
	public int getRange(){

		return range;

	} //method: getRange



    /* ===================================================================== */
    /** This method sets the pixel location of the agent.
     *
     *  @param  l   The location of agent.
     *
     */
	public void setLocation(Point l){

		location = l;

	} //method: setLocation



    /* ===================================================================== */
    /** This method sets the gps position of the agent.
     *
     *  @param  p   The position of agent.
     *
     */
	public void setPosition(Position p){

		position = p;

	} //method: setPosition



    /* ===================================================================== */
    /** This method sets the range of the agent.
     *
     *  @param  r  The range in pixels.
     *
     */
	public void setRange(int r){

		range = r;

	} //method: setRange





    /* ===================================================================== */
    /** This method returns
     *
     *  @return
     *
     */
	public boolean isBioSensor(){

		return bioSensor;

	} //method: getName


    /* ===================================================================== */
    /** This method sets t
     *
     *  @param
     *
     */
	public void setBioSensor(boolean n){

		bioSensor = n;

	} //method: setName

    /* ===================================================================== */
    /** This method returns
     *
     *  @return
     *
     */
	public boolean isLocationSensor(){

		return locationSensor;

	} //method: getName


    /* ===================================================================== */
    /** This method sets t
     *
     *  @param
     *
     */
	public void setLocationSensor(boolean n){

		locationSensor = n;

	} //method: setName

    /* ===================================================================== */
    /** This method returns
     *
     *  @return
     *
     */
	public boolean isRoomSensor(){

		return roomSensor;

	} //method: getName


    /* ===================================================================== */
    /** This method sets t
     *
     *  @param
     *
     */
	public void setRoomSensor(boolean n){

		roomSensor = n;

	} //method: setName

    /* ===================================================================== */
    /** This method returns
     *
     *  @return
     *
     */
	public boolean isWirelessSensor(){

		return wirelessSensor;

	} //method: getName


    /* ===================================================================== */
    /** This method sets t
     *
     *  @param
     *
     */
	public void setWirelessSensor(boolean n){

		wirelessSensor = n;

	} //method: setName





    /* ===================================================================== */
    /** This method returns
     *
     *  @return
     *
     */
	public boolean isBioSensor2(){

		return bioSensor2;

	} //method: getName


    /* ===================================================================== */
    /** This method sets t
     *
     *  @param
     *
     */
	public void setBioSensor2(boolean n){

		bioSensor2 = n;

	} //method: setName

    /* ===================================================================== */
    /** This method returns
     *
     *  @return
     *
     */
	public boolean isLocationSensor2(){

		return locationSensor2;

	} //method: getName


    /* ===================================================================== */
    /** This method sets t
     *
     *  @param
     *
     */
	public void setLocationSensor2(boolean n){

		locationSensor2 = n;

	} //method: setName

    /* ===================================================================== */
    /** This method returns
     *
     *  @return
     *
     */
	public boolean isRoomSensor2(){

		return roomSensor2;

	} //method: getName


    /* ===================================================================== */
    /** This method sets t
     *
     *  @param
     *
     */
	public void setRoomSensor2(boolean n){

		roomSensor2 = n;

	} //method: setName

    /* ===================================================================== */
    /** This method returns
     *
     *  @return
     *
     */
	public boolean isWirelessSensor2(){

		return wirelessSensor2;

	} //method: getName


    /* ===================================================================== */
    /** This method sets t
     *
     *  @param
     *
     */
	public void setWirelessSensor2(boolean n){

		wirelessSensor2 = n;

	} //method: setName



} //class: Agent

