/**<pre>
 * Title: iSIM
 * Copyright: Copyright (c) 2002
 * Company:   University of Oregon Computer Science Dept.
 *
 * @author Jason Prideaux
 * @version 1.0
 * </pre>
 */

package transport.protocol;

import java.io.*;
import java.awt.*;


/* ====================================================================== */
/** This class is a RangeMessage.  It is used to determine if one wearable
 *  application is in range of another.  The app should send this message
 *  to iSIM, iSIM will then send a reply, saying whether the other app is
 *  in range or not
 *
 */
public class RangeMessage extends Sim2PMessage implements Serializable{


  	/** The true is iSIM says we can connect. */
  	private boolean inRange;

	/** The port number of wearable app that the other app wants to connect to. */
	private int agent;

	/** Optional data can be put inside this message. */
	private Object msg;


    /* ===================================================================== */
    /** This constructor initializes the Message.  Object content must be added
     *  seperately with setContent() method, and the object must be
     *  Serializable.
     *
     *  @param  to   iSIM port.
     *  @param  from   Port of app send this.
     *  @param  agent   Port of app that from wants to connect to.
     *  @param  msg   Optional data that the from might want to keep track of.
     *
     */
  	public RangeMessage(int to, int from, int agent, Object msg){
		super(to, from);

		this.agent = agent;
		this.msg = msg;

	} //Constructor


    /* ===================================================================== */
    /** This constructor initializes the Message.  Object content must be added
     *  seperately with setContent() method, and the object must be
     *  Serializable.
     *
     *  @param  to   iSIM port.
     *  @param  from   Port of app send this.
     *  @param  agent   Port of app that from wants to connect to.
     *
     */
  	public RangeMessage(int to, int from, int agent){
		super(to, from);

		this.agent = agent;

	} //Constructor


    /* ===================================================================== */
    /** This method sets true if agent and from are in range.
     *
     *  @param  boolean  true if in range.
     *
     */
	public void setInRange(boolean b){

		inRange = b;

	} //method: setInRange




    /* ===================================================================== */
    /** This method returns true if agent and from are in range.
     *
     *  @return  boolean  true if in range.
     *
     */
	public boolean isInRange(){

		return inRange;

	} //method: isInRange


    /* ===================================================================== */
    /** This method returns the port of app that is in question.
     *
     *  @return  int  The port number.
     *
     */
	public int getAgent(){

		return agent;

	} //method: getAgent


    /* ===================================================================== */
    /** This method returns the data in this message (if any).
     *
     *  @return  Object  The data.
     *
     */
	public Object getData(){

		return msg;

	} //method: getData


} //class: RangeMessage

